Struct Gisr0
#[repr(transparent)]pub struct Gisr0(pub u32);Expand description
MDMA Global Interrupt/Status Register.
Tuple Fields
0: u32Implementations
impl Gisr0
impl Gisr0
pub const fn gif(&self, n: usize) -> bool
pub const fn gif(&self, n: usize) -> bool
Channel x global interrupt flag (x=0..15) This bit is set and reset by hardware. It is a logical OR of all the Channel x interrupt flags (CTCIFx, BTIFx, BRTIFx, TEIFx) which are enabled in the interrupt mask register (CTCIEx, BTIEx, BRTIEx, TEIEx).
pub const fn set_gif(&mut self, n: usize, val: bool)
pub const fn set_gif(&mut self, n: usize, val: bool)
Channel x global interrupt flag (x=0..15) This bit is set and reset by hardware. It is a logical OR of all the Channel x interrupt flags (CTCIFx, BTIFx, BRTIFx, TEIFx) which are enabled in the interrupt mask register (CTCIEx, BTIEx, BRTIEx, TEIEx).